@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,55 +32,50 @@ public class Capture<T> implements Serializable {
 
     private static final long serialVersionUID = -4214363692271370781L;
 
-    private CaptureType type;
+    private final CaptureType type;
 
-    private final List<T> values = new ArrayList<T>(2);
+    private final List<T> values = new ArrayList<>(2);
 
     /**
      * Default constructor. Only the last element will be captured
-     *
-     * @deprecated Use {@link EasyMock#newCapture()} instead
      */
-    @Deprecated
-    public Capture() {
+    private Capture() {
         this(CaptureType.LAST);
     }
 
     /**
-     * Constructor allowing to select the capture type
+     * Constructor allowing to select the capture type.
      *
      * @param type
      *            capture type
-     * @deprecated Use {@link org.easymock.EasyMock#newCapture(CaptureType)} instead
      */
-    @Deprecated
-    public Capture(CaptureType type) {
+    private Capture(CaptureType type) {
         this.type = type;
     }
 
     /**
-     * Create a new capture instance that will keep only the last captured value
+     * Create a new capture instance that will keep only the last captured value.
      *
      * @param <T> type of the class to be captured
      * @return the new capture object
      */
     public static <T> Capture<T> newInstance() {
-        return new Capture<T>();
+        return new Capture<>();
     }
 
     /**
-     * Create a new capture instance with a specific {@link org.easymock.CaptureType}
+     * Create a new capture instance with a specific {@link org.easymock.CaptureType}.
      *
      * @param type capture type wanted
      * @param <T> type of the class to be captured
      * @return the new capture object
      */
     public static <T> Capture<T> newInstance(CaptureType type) {
-        return new Capture<T>(type);
+        return new Capture<>(type);
     }
 
     /**
-     * Will reset capture to a "nothing captured yet" state
+     * Will reset capture to a "nothing captured yet" state.
      */
     public void reset() {
         values.clear();
@@ -94,7 +89,7 @@ public class Capture<T> implements Serializable {
     }
 
     /**
-     * Return captured value
+     * Return captured value.
      *
      * @throws AssertionError
      *             if nothing was captured yet or if more than one value was
@@ -113,7 +108,7 @@ public class Capture<T> implements Serializable {
 
     /**
      * Return all captured values. It returns the actual list so you can modify
-     * it's content if needed
+     * it's content if needed.
      *
      * @return The currently captured values
      */
@@ -122,7 +117,7 @@ public class Capture<T> implements Serializable {
     }
 
     /**
-     * Used internally by the EasyMock framework to add a new captured value
+     * Used internally by the EasyMock framework to add a new captured value.
      *
      * @param value
      *            Value captured
