@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -58,7 +58,7 @@ public class ExpectedInvocation implements Serializable {
             }
             return matchers;
         }
-        List<IArgumentMatcher> result = new ArrayList<IArgumentMatcher>(invocation.getArguments().length);
+        List<IArgumentMatcher> result = new ArrayList<>(invocation.getArguments().length);
         for (Object argument : invocation.getArguments()) {
             if(argument != null && argument.getClass().isArray()) {
                 result.add(new ArrayEquals(argument));
