@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2018 the original author or authors.
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,9 @@ package org.easymock.internal;
 
 import org.easymock.*;
 
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Modifier;
 import java.util.ArrayList;
 import java.util.List;
@@ -77,8 +79,15 @@ public class Injector {
                 throw new AssertionError(e);
                 // ///CLOVER:ON
             }
-            if(testSubject == null) {
-                throw new NullPointerException("Have you forgotten to instantiate " + f.getName() + "?");
+            if (testSubject == null) {
+                // The attribute isn't initialized, try to call the default constructor
+                testSubject = instantiateTestSubject(f);
+                try {
+                    f.setAccessible(true);
+                    f.set(host, testSubject);
+                } catch (ReflectiveOperationException e) {
+                    throw new AssertionError("Failed to assign the created TestSubject to  " + f.getName(), e);
+                }
             }
             Class<?> testSubjectClass = testSubject.getClass();
             while (testSubjectClass != Object.class) {
@@ -96,6 +105,28 @@ public class Injector {
         }
     }
 
+    static <T> T instantiateTestSubject(Field f) {
+        T testSubject;
+        @SuppressWarnings("unchecked")
+        Class<T> type = (Class<T>) f.getType();
+        if(type.isMemberClass() && !Modifier.isStatic(type.getModifiers())) {
+            throw new AssertionError("TestSubject is an inner class. You need to instantiate '" + f.getName() + "' manually");
+        }
+        Constructor<T> defaultConstructor;
+        try {
+            defaultConstructor = type.getDeclaredConstructor();
+        } catch (NoSuchMethodException e) {
+            throw new AssertionError("TestSubject is null and has no default constructor. You need to instantiate '" + f.getName() + "' manually");
+        }
+        defaultConstructor.setAccessible(true);
+        try {
+            testSubject = defaultConstructor.newInstance();
+        } catch (ReflectiveOperationException e) {
+            throw new AssertionError("TestSubject is null and default constructor fails on invocation. You need to instantiate '" + f.getName() + "' manually", e);
+        }
+        return testSubject;
+    }
+
     /**
      * Create the mocks and find the fields annotated with {@link TestSubject}
      *
