@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -45,7 +45,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     public static final Range ZERO_OR_MORE = new Range(0, Integer.MAX_VALUE);
 
     /** lazily created; the proxy factory for classes */
-    private static IProxyFactory classProxyFactory;
+    private static volatile IProxyFactory classProxyFactory;
 
     private static final IProxyFactory interfaceProxyFactory = new JavaProxyFactory();
 
@@ -53,40 +53,14 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
 
     private IMocksBehavior behavior;
 
-    /**
-     * This class was kept here for compatibility reason with frameworks using EasyMock
-     * @deprecated Use org.easymock.MockType
-     */
-    @Deprecated
-    public enum MockType {
-        NICE(org.easymock.MockType.NICE),
-        DEFAULT(org.easymock.MockType.DEFAULT),
-        STRICT(org.easymock.MockType.STRICT);
+    private MockType type;
 
-        private org.easymock.MockType realType;
-
-        MockType(org.easymock.MockType realType) {
-            this.realType = realType;
-        }
-
-        public org.easymock.MockType getRealType() {
-            return realType;
-        }
-    }
-
-    private org.easymock.MockType type;
-
-    public MocksControl(org.easymock.MockType type) {
+    public MocksControl(MockType type) {
         this.type = type;
         reset();
     }
 
-    public MocksControl(MockType type) {
-        this.type = type.realType;
-        reset();
-    }
-
-    public org.easymock.MockType getType() {
+    public MockType getType() {
         return type;
     }
 
@@ -95,17 +69,17 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     }
 
     @Override
-    public <T> T createMock(Class<T> toMock) {
+    public <T, R> R createMock(Class<T> toMock) {
         return createMock(null, toMock, null, (Method[]) null);
     }
 
     @Override
-    public <T> T createMock(String name, Class<T> toMock) {
+    public <T, R> R createMock(String name, Class<T> toMock) {
         return createMock(name, toMock, null, (Method[]) null);
     }
 
     @Override
-    public <T> T createMock(String name, Class<T> toMock, ConstructorArgs constructorArgs,
+    public <T, R> R createMock(String name, Class<T> toMock, ConstructorArgs constructorArgs,
             Method... mockedMethods) {
         if (toMock == null) {
             throw new NullPointerException("Can't mock 'null'");
@@ -120,8 +94,10 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
                     ? interfaceProxyFactory
                     : getClassProxyFactory();
             try {
-                return proxyFactory.createProxy(toMock, new ObjectMethodsFilter(toMock,
-                        new MockInvocationHandler(this), name), mockedMethods, constructorArgs);
+                @SuppressWarnings("unchecked")
+                R mock = (R) proxyFactory.createProxy(toMock, new ObjectMethodsFilter(toMock,
+                    new MockInvocationHandler(this), name), mockedMethods, constructorArgs);
+                return mock;
             } catch (NoClassDefFoundError e) {
                 if(e.getMessage().startsWith("org/objenesis")) {
                     throw new RuntimeExceptionWrapper(new RuntimeException(
@@ -137,7 +113,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
 
     public static IProxyFactory getProxyFactory(Object o) {
         return Proxy.isProxyClass(o.getClass())
-                ? new JavaProxyFactory()
+                ? interfaceProxyFactory
                 : getClassProxyFactory();
     }
 
@@ -174,7 +150,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     }
 
     public static InvocationHandler getInvocationHandler(Object mock) {
-        return getClassProxyFactory().getInvocationHandler(mock);
+        return getProxyFactory(mock).getInvocationHandler(mock);
     }
 
     /**
@@ -197,24 +173,6 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
         return (Class<R>) proxy.getClass().getSuperclass();
     }
 
-    /**
-     * Return the class of interface (depending on the mock type) that was
-     * mocked
-     *
-     * @param <T>
-     *            Mocked class
-     * @param <R>
-     *            Mock class
-     * @param proxy
-     *            Mock object
-     * @return the mocked class or interface
-     * @deprecated use {@link #getMockedClass(Object)} instead
-     */
-    @Deprecated
-    public static <T,  R extends T> Class<R> getMockedType(T proxy) {
-        return getMockedClass(proxy);
-    }
-
     @Override
     public void reset() {
         behavior = new MocksBehavior(type == org.easymock.MockType.NICE);
@@ -225,19 +183,19 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
 
     @Override
     public void resetToNice() {
-        type = org.easymock.MockType.NICE;
+        type = MockType.NICE;
         reset();
     }
 
     @Override
     public void resetToDefault() {
-        type = org.easymock.MockType.DEFAULT;
+        type = MockType.DEFAULT;
         reset();
     }
 
     @Override
     public void resetToStrict() {
-        type = org.easymock.MockType.STRICT;
+        type = MockType.STRICT;
         reset();
     }
 
@@ -335,7 +293,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     }
 
     @Override
-    public IExpectationSetters<Object> andAnswer(IAnswer<? extends Object> answer) {
+    public IExpectationSetters<Object> andAnswer(IAnswer<?> answer) {
         try {
             state.andAnswer(answer);
             return this;
@@ -383,7 +341,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     }
 
     @Override
-    public void andStubAnswer(IAnswer<? extends Object> answer) {
+    public void andStubAnswer(IAnswer<?> answer) {
         try {
             state.andStubAnswer(answer);
         } catch (RuntimeExceptionWrapper e) {
