@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,12 +29,7 @@ public class ObjectMethodsFilter implements InvocationHandler, Serializable {
 
     private static final long serialVersionUID = -1726286682930686024L;
 
-    private static final ReflectionUtils.Predicate<Method> NOT_PRIVATE = new ReflectionUtils.Predicate<Method>() {
-        @Override
-        public boolean test(Method method) {
-            return !Modifier.isPrivate(method.getModifiers());
-        }
-    };
+    private static final ReflectionUtils.Predicate<Method> NOT_PRIVATE = method -> !Modifier.isPrivate(method.getModifiers());
 
     private transient Method equalsMethod;
 
@@ -76,6 +71,10 @@ public class ObjectMethodsFilter implements InvocationHandler, Serializable {
         this.name = name;
     }
 
+    public String getName() {
+        return name;
+    }
+
     private static Method extractMethod(Class<?> toMock, String name, Class<?>... params) throws NoSuchMethodException {
         Method m = toMock.getMethod(name, params);
         // It can occur that the method was bridged. Usually, this means the method was in package scope on a parent class
@@ -88,10 +87,10 @@ public class ObjectMethodsFilter implements InvocationHandler, Serializable {
 
     public final Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
         if (equalsMethod.equals(method)) {
-            return Boolean.valueOf(proxy == args[0]);
+            return proxy == args[0];
         }
         if (hashCodeMethod.equals(method)) {
-            return Integer.valueOf(System.identityHashCode(proxy));
+            return System.identityHashCode(proxy);
         }
         if (toStringMethod.equals(method)) {
             return mockToString(proxy);
