@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2018 the original author or authors.
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,7 @@
  */
 package org.easymock.internal;
 
-import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.ExpectedException;
 
 import static org.junit.Assert.*;
 
@@ -26,9 +24,6 @@ import static org.junit.Assert.*;
  */
 public class LinkedClassLoaderTest {
 
-    @Rule
-    public ExpectedException expectedException = ExpectedException.none();
-
     @Test
     public void findClass() throws Exception {
         OneClassLoader stringLoader = new OneClassLoader(String.class.getName(), getClass().getClassLoader());
@@ -37,8 +32,7 @@ public class LinkedClassLoaderTest {
         assertSame(String.class, classLoader.findClass(String.class.getName()));
         assertSame(getClass(), classLoader.findClass(getClass().getName()));
 
-        expectedException.expect(ClassNotFoundException.class);
-        classLoader.findClass(Test.class.getName());
+        assertThrows(ClassNotFoundException.class, () -> classLoader.findClass(Test.class.getName()));
     }
 
 }
