@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,20 +24,20 @@ import static org.junit.Assert.*;
  */
 public class PrimitiveUtilsTest {
     @Test
-    public void getEmptyValue() throws Exception {
-        assertEquals(null, PrimitiveUtils.getEmptyValue(Void.TYPE));
+    public void getEmptyValue() {
+        assertNull(PrimitiveUtils.getEmptyValue(Void.TYPE));
         assertEquals(false, PrimitiveUtils.getEmptyValue(Boolean.TYPE));
-        assertEquals(Byte.valueOf((byte) 0), PrimitiveUtils.getEmptyValue(Byte.TYPE));
-        assertEquals(Short.valueOf((short) 0), PrimitiveUtils.getEmptyValue(Short.TYPE));
-        assertEquals(Character.valueOf((char) 0), PrimitiveUtils.getEmptyValue(Character.TYPE));
-        assertEquals(Integer.valueOf(0), PrimitiveUtils.getEmptyValue(Integer.TYPE));
-        assertEquals(Long.valueOf(0), PrimitiveUtils.getEmptyValue(Long.TYPE));
-        assertEquals(Float.valueOf(0), PrimitiveUtils.getEmptyValue(Float.TYPE));
-        assertEquals(Double.valueOf(0), PrimitiveUtils.getEmptyValue(Double.TYPE));
+        assertEquals((byte) 0, PrimitiveUtils.getEmptyValue(Byte.TYPE));
+        assertEquals((short) 0, PrimitiveUtils.getEmptyValue(Short.TYPE));
+        assertEquals((char) 0, PrimitiveUtils.getEmptyValue(Character.TYPE));
+        assertEquals(0, PrimitiveUtils.getEmptyValue(Integer.TYPE));
+        assertEquals(0L, PrimitiveUtils.getEmptyValue(Long.TYPE));
+        assertEquals((float) 0, PrimitiveUtils.getEmptyValue(Float.TYPE));
+        assertEquals((double) 0, PrimitiveUtils.getEmptyValue(Double.TYPE));
     }
 
     @Test
-    public void getWrapperType() throws Exception {
+    public void getWrapperType() {
         assertEquals(Void.class, PrimitiveUtils.getWrapperType(Void.TYPE));
         assertEquals(Boolean.class, PrimitiveUtils.getWrapperType(Boolean.TYPE));
         assertEquals(Byte.class, PrimitiveUtils.getWrapperType(Byte.TYPE));
@@ -50,7 +50,7 @@ public class PrimitiveUtilsTest {
     }
 
     @Test
-    public void isNumberWrapper() throws Exception {
+    public void isNumberWrapper() {
         assertTrue(PrimitiveUtils.isPrimitiveWrapper(Byte.class));
         assertTrue(PrimitiveUtils.isPrimitiveWrapper(Short.class));
         assertTrue(PrimitiveUtils.isPrimitiveWrapper(Integer.class));
@@ -63,7 +63,7 @@ public class PrimitiveUtilsTest {
     }
 
     @Test
-    public void getPrimitiveTypeNameFromWrapper() throws Exception {
+    public void getPrimitiveTypeNameFromWrapper() {
         assertPrimitiveName(Byte.TYPE, Byte.class);
         assertPrimitiveName(Short.TYPE, Short.class);
         assertPrimitiveName(Integer.TYPE, Integer.class);
