@@ -1,5 +1,5 @@
-/**
- * Copyright 2001-2018 the original author or authors.
+/*
+ * Copyright 2001-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ import org.junit.Test;
 public class ClassInstantiatorFactoryTest {
 
     @After
-    public void tearDown() throws Exception {
+    public void tearDown() {
         // put back the default to prevent side effects on other tests
         ClassInstantiatorFactory.setDefaultInstantiator();
     }
@@ -42,7 +42,7 @@ public class ClassInstantiatorFactoryTest {
     }
 
     @Test
-    public void getInstantiator_Overriden() {
+    public void getInstantiator_Overridden() {
         ClassInstantiatorFactory.setInstantiator(new DefaultClassInstantiator());
         IClassInstantiator instantiator = ClassInstantiatorFactory.getInstantiator();
         assertTrue(instantiator instanceof DefaultClassInstantiator);
