@@ -1,5 +1,5 @@
-/**
- * Copyright 2009-2018 the original author or authors.
+/*
+ * Copyright 2009-2020 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,7 +43,7 @@ import static org.powermock.api.easymock.PowerMock.*;
 public class PowermockTest {
 
     @Test
-    public void testMockStatic() throws Exception {
+    public void testMockStatic() {
         mockStatic(StaticService.class);
 
         String expected = "Hello altered World";
